==> aws-sdk-cpp-1.11.667-1-x86_64.pkg.tar.zst: usr/include/aws/ivs-realtime/IvsrealtimeEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/ivs-realtime/Ivsrealtime_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/ivs-realtime/IvsrealtimeEndpointRules.h>


namespace Aws
{
namespace ivsrealtime
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using IvsrealtimeClientContextParameters = Aws::Endpoint::ClientContextParameters;

using IvsrealtimeClientConfiguration = Aws::Client::GenericClientConfiguration;
using IvsrealtimeBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the ivsrealtime Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using IvsrealtimeEndpointProviderBase =
    EndpointProviderBase<IvsrealtimeClientConfiguration, IvsrealtimeBuiltInParameters, IvsrealtimeClientContextParameters>;

using IvsrealtimeDefaultEpProviderBase =
    DefaultEndpointProvider<IvsrealtimeClientConfiguration, IvsrealtimeBuiltInParameters, IvsrealtimeClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_IVSREALTIME_API IvsrealtimeEndpointProvider : public IvsrealtimeDefaultEpProviderBase
{
public:
    using IvsrealtimeResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    IvsrealtimeEndpointProvider()
      : IvsrealtimeDefaultEpProviderBase(Aws::ivsrealtime::IvsrealtimeEndpointRules::GetRulesBlob(), Aws::ivsrealtime::IvsrealtimeEndpointRules::RulesBlobSize)
    {}

    ~IvsrealtimeEndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace ivsrealtime
} // namespace Aws

==> aws-sdk-cpp-1.11.710-1-x86_64.pkg.tar.zst: usr/include/aws/ivs-realtime/IvsrealtimeEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/ivs-realtime/IvsrealtimeEndpointRules.h>
#include <aws/ivs-realtime/Ivsrealtime_EXPORTS.h>

namespace Aws {
namespace ivsrealtime {
namespace Endpoint {
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::DefaultEndpointProvider;
using Aws::Endpoint::EndpointProviderBase;

using IvsrealtimeClientContextParameters = Aws::Endpoint::ClientContextParameters;

using IvsrealtimeClientConfiguration = Aws::Client::GenericClientConfiguration;
using IvsrealtimeBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the ivsrealtime Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using IvsrealtimeEndpointProviderBase =
    EndpointProviderBase<IvsrealtimeClientConfiguration, IvsrealtimeBuiltInParameters, IvsrealtimeClientContextParameters>;

using IvsrealtimeDefaultEpProviderBase =
    DefaultEndpointProvider<IvsrealtimeClientConfiguration, IvsrealtimeBuiltInParameters, IvsrealtimeClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_IVSREALTIME_API IvsrealtimeEndpointProvider : public IvsrealtimeDefaultEpProviderBase {
 public:
  using IvsrealtimeResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

  IvsrealtimeEndpointProvider()
      : IvsrealtimeDefaultEpProviderBase(Aws::ivsrealtime::IvsrealtimeEndpointRules::GetRulesBlob(),
                                         Aws::ivsrealtime::IvsrealtimeEndpointRules::RulesBlobSize) {}

  ~IvsrealtimeEndpointProvider() {}
};
}  // namespace Endpoint
}  // namespace ivsrealtime
}  // namespace Aws
